applyTheme method

  1. @override
void applyTheme(
  1. GeneratedPalette palette
)
override

Apply colors from a GeneratedPalette to this component's state.

This method is called when the theme changes or when a new palette is generated. It should update all color properties based on the palette's values.

Implementation should use ThemeColorMapper.forComponent() for component-specific color resolution.

Implementation

@override
void applyTheme(GeneratedPalette palette) {
  super.applyTheme(palette);

  final colors = ThemeColorMapper.forComponent(palette, componentName);

  // Hint colors use icon color
  restHintColorLight = colors.restIconColorLight;
  restHintColorDark = colors.restIconColorDark;
  hoverHintColorLight = colors.hoverIconColorLight;
  hoverHintColorDark = colors.hoverIconColorDark;
  pressedHintColorLight = colors.pressedIconColorLight;
  pressedHintColorDark = colors.pressedIconColorDark;
  disabledHintColorLight = colors.disabledIconColorLight;
  disabledHintColorDark = colors.disabledIconColorDark;

  // Dropdown menu uses rest colors
  restDropdownBgColorLight = colors.restBaseColorLight;
  restDropdownBgColorDark = colors.restBaseColorDark;
  restDropdownItemColorLight = colors.restTextColorLight;
  restDropdownItemColorDark = colors.restTextColorDark;

  // Border color
  borderColor = colors.accentColorLight;
}