applyTheme method

  1. @override
void applyTheme(
  1. GeneratedPalette palette
)
override

Apply colors from a GeneratedPalette to this component's state.

This method is called when the theme changes or when a new palette is generated. It should update all color properties based on the palette's values.

Implementation should use ThemeColorMapper.forComponent() for component-specific color resolution.

Implementation

@override
void applyTheme(GeneratedPalette palette) {
  super.applyTheme(palette);

  final colors = ThemeColorMapper.forComponent(palette, componentName);

  // Selected colors use accent
  restSelectedColorLight = colors.accentColorLight;
  restSelectedColorDark = colors.accentColorDark;

  hoverSelectedColorLight = colors.accentColorLight;
  hoverSelectedColorDark = colors.accentColorDark;

  pressedSelectedColorLight = colors.accentColorLight;
  pressedSelectedColorDark = colors.accentColorDark;

  disabledSelectedColorLight = colors.disabledIconColorLight;
  disabledSelectedColorDark = colors.disabledIconColorDark;
}