DeviceFrameToolbar class

A toolbar for selecting device presets and orientation

Inheritance

Constructors

DeviceFrameToolbar({Key? key, required DevicePreset selectedDevice, required DeviceOrientation orientation, required ValueChanged<DevicePreset> onDeviceChanged, required ValueChanged<DeviceOrientation> onOrientationChanged, double paddingVertical = 0, double paddingHorizontal = 0, ValueChanged<double>? onPaddingVerticalChanged, ValueChanged<double>? onPaddingHorizontalChanged})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDeviceChanged ValueChanged<DevicePreset>
final
onOrientationChanged ValueChanged<DeviceOrientation>
final
onPaddingHorizontalChanged ValueChanged<double>?
Callback when horizontal padding changes
final
onPaddingVerticalChanged ValueChanged<double>?
Callback when vertical padding changes
final
orientation DeviceOrientation
final
paddingHorizontal double
Horizontal padding for component in device frame mode
final
paddingVertical double
Vertical padding for component in device frame mode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDevice DevicePreset
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited