DeviceCategory enum

Device categories for grouping

Inheritance
Available extensions

Values

none → const DeviceCategory
const DeviceCategory('None')
mobileSmall → const DeviceCategory
const DeviceCategory('Mobile Small')
mobileMedium → const DeviceCategory
const DeviceCategory('Mobile Medium')
mobileLarge → const DeviceCategory
const DeviceCategory('Mobile Large')
tabletSmall → const DeviceCategory
const DeviceCategory('Tablet Small')
tabletMedium → const DeviceCategory
const DeviceCategory('Tablet Medium')
tabletLarge → const DeviceCategory
const DeviceCategory('Tablet Large')
desktop → const DeviceCategory
const DeviceCategory('Desktop')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DeviceCategory>
A constant List of the values in this enum, in order of their declaration.