DevicePreset enum

Device preset definitions for preview frames

Inheritance
Available extensions

Values

none → const DevicePreset
const DevicePreset('No Frame', 0, 0, DeviceCategory.none)
iphoneSE → const DevicePreset
const DevicePreset('iPhone SE', 375, 667, DeviceCategory.mobileSmall)
iphone14 → const DevicePreset
const DevicePreset('iPhone 14', 390, 844, DeviceCategory.mobileMedium)
iphone14ProMax → const DevicePreset
const DevicePreset('iPhone 14 Pro Max', 430, 932, DeviceCategory.mobileLarge)
ipadMini → const DevicePreset
const DevicePreset('iPad Mini', 744, 1133, DeviceCategory.tabletSmall)
ipadPro11 → const DevicePreset
const DevicePreset('iPad Pro 11"', 834, 1194, DeviceCategory.tabletMedium)
ipadPro12 → const DevicePreset
const DevicePreset('iPad Pro 12.9"', 1024, 1366, DeviceCategory.tabletLarge)
desktop → const DevicePreset
const DevicePreset('Desktop', 1440, 900, DeviceCategory.desktop)

Properties

aspectRatio double
Get aspect ratio
no setter
category DeviceCategory
final
dimensionLabel String
Get dimension label (e.g., "390 × 844")
no setter
displayName String
final
hashCode int
The hash code for this object.
no setterinherited
hasNotch bool
Whether this device has a notch
no setter
height double
final
index int
A numeric identifier for the enumerated value.
no setterinherited
isIOS bool
Whether this is an iOS device (for notch rendering)
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
final

Methods

getSize(DeviceOrientation orientation) Size

Available on DevicePreset, provided by the DevicePresetExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DevicePreset>
A constant List of the values in this enum, in order of their declaration.