PreviewBackground enum
Background options for preview area
Values
- neumorphicLight → const PreviewBackground
-
const PreviewBackground('Neumorphic Light', ColorTokens.neumorphicLight) - neumorphicDark → const PreviewBackground
-
const PreviewBackground('Neumorphic Dark', ColorTokens.neumorphicDark) - white → const PreviewBackground
-
const PreviewBackground('White', Colors.white) - black → const PreviewBackground
-
const PreviewBackground('Black', Colors.black) - custom → const PreviewBackground
-
const PreviewBackground('Custom...', Colors.grey)
Properties
- defaultColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PreviewBackground> - A constant List of the values in this enum, in order of their declaration.