ResettableState mixin

Mixin that provides reset functionality for component states

Components implementing this mixin can be reset to their default values. The resetToDefaults method should be overridden to reset all properties.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromSnapshot(Map<String, dynamic> snapshot) → void
Restores state from a snapshot (optional)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetToDefaults() → void
Resets all properties to their default values
toSnapshot() Map<String, dynamic>?
Creates a copy of the current state for undo functionality (optional)
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited