BorderTokens class abstract
============================================================================= BORDER WIDTH TOKENS
Consistent border widths for outlines and dividers.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- extraThick → const double
- 4.0px - Extra thick (heavy emphasis)
- hairline → const double
- 0.5px - Hairline (subtle dividers)
- medium → const double
- 2.0px - Medium (emphasis borders) - COMMON
- mediumThin → const double
- 1.5px - Medium-thin
- thick → const double
- 3.0px - Thick (animated borders, focus rings)
- thin → const double
- 1.0px - Thin (standard borders)