OpacityTokens class abstract

============================================================================= OPACITY TOKENS

Consistent opacity values for transparency effects.

Constructors

OpacityTokens()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

heavy → const double
0.87 - Heavy (text on backgrounds)
light → const double
0.2 - Light (disabled state backgrounds)
medium → const double
0.5 - Medium (disabled elements) - COMMON
mediumHeavy → const double
0.7 - Medium-heavy (modal backgrounds)
mediumLight → const double
0.3 - Medium-light (scrim, light overlays)
opaque → const double
1.0 - Fully opaque
transparent → const double
0.0 - Fully transparent
ultraLight → const double
0.05 - Barely visible (subtle overlays)
veryLight → const double
0.1 - Very light (hover backgrounds)