NeumorphicStateProperties class

Neumorphic properties for a specific state (rest, hover, pressed, disabled)

Contains both shadow properties and pre-calculated colors from Theme Creator. The colors are the absolute source of truth for component rendering.

Constructors

NeumorphicStateProperties({required double distance, required double blur, required double lightIntensity, required double darkIntensity, required double borderRadius, String surfaceColorRole = 'surface', String accentColorRole = 'primary', Color? baseColor, Color? textColor, Color? iconColor, Color? lightShadowColor, Color? darkShadowColor})
const
NeumorphicStateProperties.fromJson(Map<String, dynamic> json)
factory

Properties

accentColorRole String
final
baseColor Color?
Base/surface color for this state (pre-calculated by ThemeColorMapper)
final
blur double
final
borderRadius double
final
darkIntensity double
final
darkShadowColor Color?
Dark shadow color (bottom-right shadow)
final
distance double
final
hashCode int
The hash code for this object.
no setterinherited
iconColor Color?
Icon color for this state (pre-calculated by ThemeColorMapper)
final
lightIntensity double
final
lightShadowColor Color?
Light shadow color (top-left highlight)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surfaceColorRole String
final
textColor Color?
Text color for this state (pre-calculated by ThemeColorMapper)
final

Methods

copyWith({double? distance, double? blur, double? lightIntensity, double? darkIntensity, double? borderRadius, String? surfaceColorRole, String? accentColorRole, Color? baseColor, Color? textColor, Color? iconColor, Color? lightShadowColor, Color? darkShadowColor}) NeumorphicStateProperties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited