NeumorphicThemeExtension class

Theme extension for neumorphic properties Access via: Theme.of(context).extension<NeumorphicThemeExtension>()

Inheritance

Constructors

NeumorphicThemeExtension({required NeumorphicStateProperties rest, required NeumorphicStateProperties hover, required NeumorphicStateProperties pressed, required NeumorphicStateProperties disabled})
const

Properties

disabled NeumorphicStateProperties
final
hashCode int
The hash code for this object.
no setterinherited
hover NeumorphicStateProperties
final
pressed NeumorphicStateProperties
final
rest NeumorphicStateProperties
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Object
The extension's type.
no setterinherited

Methods

copyWith({NeumorphicStateProperties? rest, NeumorphicStateProperties? hover, NeumorphicStateProperties? pressed, NeumorphicStateProperties? disabled}) ThemeExtension<NeumorphicThemeExtension>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
forState(ComponentState state) NeumorphicStateProperties
Convenience method to get state properties
lerp(covariant ThemeExtension<NeumorphicThemeExtension>? other, double t) ThemeExtension<NeumorphicThemeExtension>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited