requiresAnimationController property
Whether this component requires an animation controller. If true, the workbench will pass its shared animation controller to the preview builder.
Implementation
final bool requiresAnimationController;
Whether this component requires an animation controller. If true, the workbench will pass its shared animation controller to the preview builder.
final bool requiresAnimationController;