getModifiedProperties abstract method

Set<String> getModifiedProperties()

Get the set of property names that have been modified from defaults.

This is used to track which colors the user has customized, enabling the "pending overrides" indicator in the workbench UI.

Returns a set of string identifiers like 'restBaseColor', 'textSize', etc.

Implementation

Set<String> getModifiedProperties();