TopBar class
Top bar for the Component Prototyping Workbench Contains logo, title, theme dropdown, Save Changes button, and global action buttons
- Inheritance
Constructors
-
TopBar({Key? key, VoidCallback? onSettingsPressed, VoidCallback? onHelpPressed, VoidCallback? onFactoryResetDefaultTheme, List<
SavedTheme> savedThemes = const [], String currentThemeName = 'Default', ValueChanged<SavedTheme> ? onThemeSelected, bool isLoadingThemes = false, bool hasUnsavedChanges = false, VoidCallback? onSaveChanges}) -
const
Properties
- currentThemeName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasUnsavedChanges → bool
-
Whether there are unsaved color changes (Phase 8)
final
- isLoadingThemes → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onFactoryResetDefaultTheme → VoidCallback?
-
Callback when Factory Reset Default Theme is selected
final
- onHelpPressed → VoidCallback?
-
final
- onSaveChanges → VoidCallback?
-
Callback when Save Changes button is pressed (Phase 8)
final
- onSettingsPressed → VoidCallback?
-
final
-
onThemeSelected
→ ValueChanged<
SavedTheme> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
savedThemes
→ List<
SavedTheme> -
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited