applyTheme method
Apply colors from a GeneratedPalette to this component's state.
This method is called when the theme changes or when a new palette is generated. It should update all color properties based on the palette's values.
Implementation should use ThemeColorMapper.forComponent() for component-specific color resolution.
Implementation
@override
void applyTheme(GeneratedPalette palette) {
super.applyTheme(palette);
final colors = ThemeColorMapper.forComponent(palette, componentName);
// Container primarily uses rest and disabled states
restBaseColorLight = colors.restBaseColorLight;
restBaseColorDark = colors.restBaseColorDark;
restTextColorLight = colors.restIconColorLight;
restTextColorDark = colors.restIconColorDark;
disabledBaseColorLight = colors.disabledBaseColorLight;
disabledBaseColorDark = colors.disabledBaseColorDark;
disabledTextColorLight = colors.disabledTextColorLight;
disabledTextColorDark = colors.disabledTextColorDark;
}