applyTheme method
Apply colors from a GeneratedPalette to this component's state.
This method is called when the theme changes or when a new palette is generated. It should update all color properties based on the palette's values.
Implementation should use ThemeColorMapper.forComponent() for component-specific color resolution.
Implementation
@override
void applyTheme(GeneratedPalette palette) {
super.applyTheme(palette);
final colors = ThemeColorMapper.forComponent(palette, componentName);
// Accent colors from palette
restAccentColorLight = colors.accentColorLight;
restAccentColorDark = colors.accentColorDark;
hoverAccentColorLight = colors.accentColorLight;
hoverAccentColorDark = colors.accentColorDark;
pressedAccentColorLight = colors.accentColorLight;
pressedAccentColorDark = colors.accentColorDark;
disabledAccentColorLight = colors.disabledIconColorLight;
disabledAccentColorDark = colors.disabledIconColorDark;
}