playground/utils/state_variants_wrapper
library
Classes
-
PreviewBackgroundWrapper
-
Widget that wraps a preview and injects themedBackgroundColor into any
StateVariantsWrapper descendants by rebuilding them with the color parameter.
This provides a more reliable mechanism than InheritedWidget for passing
the background color to registry-created previews.
-
StateVariantsWrapper
-
Wrapper that displays component state variants in different modes
-
ThemedBackgroundProvider
-
InheritedWidget to provide themed background color from palette
to StateVariantsWrapper without modifying all component definitions.