NeumorphicTheme class
Complete theme definition for neumorphic design system
Constructors
- NeumorphicTheme({required String name, required Brightness brightness, required Color seedColor, required ColorScheme colorScheme, required NeumorphicStateProperties rest, required NeumorphicStateProperties hover, required NeumorphicStateProperties pressed, required NeumorphicStateProperties disabled, TextTheme? textTheme})
-
const
Properties
- brightness → Brightness
-
final
- colorScheme → ColorScheme
-
final
- disabled → NeumorphicStateProperties
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hover → NeumorphicStateProperties
-
final
- name → String
-
final
- pressed → NeumorphicStateProperties
-
final
- rest → NeumorphicStateProperties
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seedColor → Color
-
final
- textTheme → TextTheme?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFlutterCode(
) → String - Generate Flutter code
-
toJson(
) → Map< String, dynamic> - Serialize to JSON
-
toString(
) → String -
A string representation of this object.
inherited
-
toThemeData(
) → ThemeData - Convert to Flutter ThemeData
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited