ThemePair class

Holds light and dark theme pair

Constructors

ThemePair({required NeumorphicTheme light, required NeumorphicTheme dark})
const

Properties

dark NeumorphicTheme
final
hashCode int
The hash code for this object.
no setterinherited
light NeumorphicTheme
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

forBrightness(Brightness brightness) NeumorphicTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited